==> mingw-w64-aws-sdk-cpp-1.9.311-1.src.tar.zst: aws-sdk-cpp-1.9.311/aws-cpp-sdk-config/source/model/ListConformancePackComplianceScoresResult.cpp <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/config/model/ListConformancePackComplianceScoresResult.h>
#include <aws/core/utils/json/JsonSerializer.h>
#include <aws/core/AmazonWebServiceResult.h>
#include <aws/core/utils/StringUtils.h>
#include <aws/core/utils/UnreferencedParam.h>

#include <utility>

using namespace Aws::ConfigService::Model;
using namespace Aws::Utils::Json;
using namespace Aws::Utils;
using namespace Aws;

ListConformancePackComplianceScoresResult::ListConformancePackComplianceScoresResult()
{
}

ListConformancePackComplianceScoresResult::ListConformancePackComplianceScoresResult(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  *this = result;
}

ListConformancePackComplianceScoresResult& ListConformancePackComplianceScoresResult::operator =(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  JsonView jsonValue = result.GetPayload().View();
  if(jsonValue.ValueExists("NextToken"))
  {
    m_nextToken = jsonValue.GetString("NextToken");

  }

  if(jsonValue.ValueExists("ConformancePackComplianceScores"))
  {
    Array<JsonView> conformancePackComplianceScoresJsonList = jsonValue.GetArray("ConformancePackComplianceScores");
    for(unsigned conformancePackComplianceScoresIndex = 0; conformancePackComplianceScoresIndex < conformancePackComplianceScoresJsonList.GetLength(); ++conformancePackComplianceScoresIndex)
    {
      m_conformancePackComplianceScores.push_back(conformancePackComplianceScoresJsonList[conformancePackComplianceScoresIndex].AsObject());
    }
  }



  return *this;
}

==> mingw-w64-aws-sdk-cpp-1.10.9-1.src.tar.zst: aws-sdk-cpp-1.10.9/aws-cpp-sdk-config/source/model/ListConformancePackComplianceScoresResult.cpp <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/config/model/ListConformancePackComplianceScoresResult.h>
#include <aws/core/utils/json/JsonSerializer.h>
#include <aws/core/AmazonWebServiceResult.h>
#include <aws/core/utils/StringUtils.h>
#include <aws/core/utils/UnreferencedParam.h>

#include <utility>

using namespace Aws::ConfigService::Model;
using namespace Aws::Utils::Json;
using namespace Aws::Utils;
using namespace Aws;

ListConformancePackComplianceScoresResult::ListConformancePackComplianceScoresResult()
{
}

ListConformancePackComplianceScoresResult::ListConformancePackComplianceScoresResult(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  *this = result;
}

ListConformancePackComplianceScoresResult& ListConformancePackComplianceScoresResult::operator =(const Aws::AmazonWebServiceResult<JsonValue>& result)
{
  JsonView jsonValue = result.GetPayload().View();
  if(jsonValue.ValueExists("NextToken"))
  {
    m_nextToken = jsonValue.GetString("NextToken");

  }

  if(jsonValue.ValueExists("ConformancePackComplianceScores"))
  {
    Aws::Utils::Array<JsonView> conformancePackComplianceScoresJsonList = jsonValue.GetArray("ConformancePackComplianceScores");
    for(unsigned conformancePackComplianceScoresIndex = 0; conformancePackComplianceScoresIndex < conformancePackComplianceScoresJsonList.GetLength(); ++conformancePackComplianceScoresIndex)
    {
      m_conformancePackComplianceScores.push_back(conformancePackComplianceScoresJsonList[conformancePackComplianceScoresIndex].AsObject());
    }
  }



  return *this;
}
